@@ -55,6 +55,8 @@ GType gvir_config_domain_disk_snapshot_type_get_type (void) G_GNUC_CONST;
 #define GVIR_CONFIG_TYPE_DOMAIN_DISK_SNAPSHOT_TYPE (gvir_config_domain_disk_snapshot_type_get_type ())
 GType gvir_config_domain_disk_startup_policy_get_type (void) G_GNUC_CONST;
 #define GVIR_CONFIG_TYPE_DOMAIN_DISK_STARTUP_POLICY (gvir_config_domain_disk_startup_policy_get_type ())
+GType gvir_config_domain_disk_format_get_type (void) G_GNUC_CONST;
+#define GVIR_CONFIG_TYPE_DOMAIN_DISK_FORMAT (gvir_config_domain_disk_format_get_type ())
 
 /* enumerations from "./libvirt-gconfig-domain-filesys.h" */
 GType gvir_config_domain_filesys_type_get_type (void) G_GNUC_CONST;
@@ -98,6 +100,12 @@ GType gvir_config_domain_redirdev_bus_get_type (void) G_GNUC_CONST;
 GType gvir_config_domain_seclabel_type_get_type (void) G_GNUC_CONST;
 #define GVIR_CONFIG_TYPE_DOMAIN_SECLABEL_TYPE (gvir_config_domain_seclabel_type_get_type ())
 
+/* enumerations from "./libvirt-gconfig-domain-snapshot.h" */
+GType gvir_config_domain_snapshot_domain_state_get_type (void) G_GNUC_CONST;
+#define GVIR_CONFIG_TYPE_DOMAIN_SNAPSHOT_DOMAIN_STATE (gvir_config_domain_snapshot_domain_state_get_type ())
+GType gvir_config_domain_snapshot_memory_state_get_type (void) G_GNUC_CONST;
+#define GVIR_CONFIG_TYPE_DOMAIN_SNAPSHOT_MEMORY_STATE (gvir_config_domain_snapshot_memory_state_get_type ())
+
 /* enumerations from "./libvirt-gconfig-domain-sound.h" */
 GType gvir_config_domain_sound_model_get_type (void) G_GNUC_CONST;
 #define GVIR_CONFIG_TYPE_DOMAIN_SOUND_MODEL (gvir_config_domain_sound_model_get_type ())
